# Getting Started with EP Reference Components

This project provides React commerce enabled components that connect to Elastic Path.

More information on this module can be found [here](https://www.drupal.org/project/ep_reference_components).

## Assumptions
This guides assumes you already have the following installed.
* Composer
* npm

## Pulling down the module with Composer
Adding EP reference components to your project can be done with just one command from the root of your project:

`composer require 'drupal/ep_reference_components:^1.0'`

This will add ep_reference_components into your composer.json and install all the other required modules, including EP React Block. More information on that module can be found [here](https://www.drupal.org/project/ep_react_blocks).
## Running scripts
Since these are react components they need to be compiled before they will display on your site. 

1. From the root of your project, navigate into `modules/contrib/ep_reference_components`
2. Open a bash terminal in this directory
3. Run `npm install`
4. Run `npm run-script build-webpack`
5. Run `npm run-script build-component-less`
6. Clear Drupal cache

## Enabling EP Reference component Module
To get the component blocks to appear when editing Structure, the module needs to be enabled first. 

1. Login into your Drupal admin dashboard
2. On the top menu bar, click `Extend`.
3. On the Extend page, click `EP Reference Store Components` checkbox then press Install.
4. The page will confirm any additional dependencies that need to be installed. Press continue if this page appears.

Now you are ready to use EP Reference components on your site!

## Using EP Reference Components on your site

1. Login into your Drupal admin dashboard
2. On the top menu bar, click `Structure`.
3. On the Structure page, click `Block Layout`.
4. Under the section you want to add an EP Reference Component to, click `Place Block`
5. Select a block that is pre-pended with EP and has a Category of EP React Blocks, press  `Place block`.
6. Configure the block then press `Save`.

Note some blocks have configuration option fields such as Image URL or colour code. More detailed descriptions are below each field.

## EP Cortex configurations
The EP Reference components need to be configured to an Elastic Path Instance. Otherwise they have limited functionality.

### Configuration Steps
1. Login into your Drupal admin dashboard
2. On the top menu bar, click `Configuration`.
3. On the Structure page, click `EP Component Cortex Configuration`.
4. Configure options and press `Save configuration`.

### Configuration Options
Below describes each option in more detail. The following options are mandatory. 

Option | Description
-------|------------
Cortex API Endpoint | The URL endpoint to connect to cortex. Example: `https://examplewebsite.com/cortex`
Scope | The Store code of your Elastic Path store
Default Locale | The default language of your store. Example: `en-CA`
Default Currency | The default currency in ISO 4217 standard. Example: `USD`
Sku Images URL | The URL to your product sku's images. Each image for a product sku should be named as the `skucode` of that SKU and a PNG. Example: `https://examplewebsite.com/images/%sku%.png`
Site Images URL | Example: `https://examplewebsite.com/images/%fileName%`
AR Images URL | `https://examplewebsite.com/images/%sku%.usdz`
Use B2B features | Specifies if you want to use B2B account management. It is unset by default. 

The following are required if `Use B2B features` is set, otherwise they can be safely ignored.

Option | Description
-------|------------
B2B Auth service API url | The URL to redirect to Account Management authentication.
B2B callback url | The URL to go back to after authentication has completed. Example: the url of your drupal site.
B2B keycloak auth url | Keycloak url that handles authorization.
B2B keycloak logout url | Keycloak url that handles logging out.

